@@ -11,34 +11,35 @@
 #'   of same class.
 #'
 #' @examples
-#' library(lme4)
-#' data(mtcars)
-#' data(sleepstudy)
+#' if (require("lme4")) {
+#'   data(mtcars)
+#'   data(sleepstudy)
 #'
-#' m1 <- lm(mpg ~ wt + cyl + vs, data = mtcars)
-#' m2 <- lm(mpg ~ wt + cyl, data = mtcars)
-#' m3 <- lmer(Reaction ~ Days + (1 | Subject), data = sleepstudy)
-#' m4 <- glm(formula = vs ~ wt, family = binomial(), data = mtcars)
-#'
-#' all_models_same_class(m1, m2)
-#' all_models_same_class(m1, m2, m3)
-#' all_models_same_class(m1, m4, m2, m3, verbose = TRUE)
-#' all_models_same_class(m1, m4, mtcars, m2, m3, verbose = TRUE)
+#'   m1 <- lm(mpg ~ wt + cyl + vs, data = mtcars)
+#'   m2 <- lm(mpg ~ wt + cyl, data = mtcars)
+#'   m3 <- lmer(Reaction ~ Days + (1 | Subject), data = sleepstudy)
+#'   m4 <- glm(formula = vs ~ wt, family = binomial(), data = mtcars)
 #'
+#'   all_models_same_class(m1, m2)
+#'   all_models_same_class(m1, m2, m3)
+#'   all_models_same_class(m1, m4, m2, m3, verbose = TRUE)
+#'   all_models_same_class(m1, m4, mtcars, m2, m3, verbose = TRUE)
+#' }
 #' @export
 all_models_equal <- function(..., verbose = FALSE) {
   objects <- list(...)
   object_names <- match.call(expand.dots = FALSE)$`...`
 
-  all_supported <- sapply(objects, is_model)
+  all_supported <- vapply(objects, is_model_supported, FUN.VALUE = logical(1))
   all_classes <- sapply(objects, class)
 
-  if (is.matrix(all_classes))
+  if (is.matrix(all_classes)) {
     all_classes <- as.vector(all_classes[1, ])
-  else if (is.list(all_classes))
+  } else if (is.list(all_classes)) {
     all_classes <- sapply(all_classes, function(i) i[1])
+  }
 
-  all_equal <- all(sapply(all_classes[-1], function(i) identical(i, all_classes[1])))
+  all_equal <- all(vapply(all_classes[-1], function(i) identical(i, all_classes[1]), FUN.VALUE = logical(1)))
 
   if (!all(all_supported) && verbose) {
     differ <- which(!all_supported)
@@ -76,4 +77,4 @@ all_models_equal <- function(..., verbose = FALSE) {
 
 #' @rdname all_models_equal
 #' @export
-all_models_same_class <- all_models_equal
\ No newline at end of file
+all_models_same_class <- all_models_equal
