@@ -3,24 +3,33 @@
 #' @param x A data frame.
 #' @param sep Column separator.
 #' @param header Header separator. Can be \code{NULL}.
+#' @param empty_line Separator used for empty lines. If \code{NULL}, line remains
+#'   empty (i.e. filled with whitespaces).
 #' @param format Name of output-format, as string. If \code{NULL} (or \code{"text"}),
-#'   returned output is used for basic printing. Currently, only \code{"markdown"} is
-#'   supported, or \code{NULL} (the default) resp. \code{"text"} for plain text.
-#' @param caption,subtitle Table caption and subtitle, as string. If \code{NULL},
-#'   no caption or subtitle is printed.
+#'   returned output is used for basic printing. Can be one of \code{NULL} (the
+#'   default) resp. \code{"text"} for plain text, \code{"markdown"} (or
+#'   \code{"md"}) for markdown and \code{"html"} for HTML output.
+#' @param title,caption,subtitle Table title (same as caption) and subtitle, as strings. If \code{NULL},
+#'   no title or subtitle is printed, unless it is stored as attributes (\code{table_title},
+#'   or its alias \code{table_caption}, and \code{table_subtitle}).
 #' @param footer Table footer, as string. For markdown-formatted tables, table
 #'   footers, due to the limitation in markdown rendering, are actually just a
 #'   new text line under the table.
-#' @param align Column alignment. Only applies to markdown-formatted tables.
-#'   By default \code{align = NULL}, numeric columns are right-aligned,
-#'   and other columns are left-aligned. May be a string to indicate alignment
-#'   rules for the complete table, like \code{"left"}, \code{"right"},
-#'   \code{"center"} or \code{"firstleft"} (to left-align first column,
-#'   center remaining); or maybe a string with abbreviated alignment characters,
-#'   where the length of the string must equal the number of columns, for
-#'   instance, \code{align = "lccrl"} would left-align the first column, center
+#' @param align Column alignment. For markdown-formatted tables, the default
+#'   \code{align = NULL} will right-align numeric columns, while all other
+#'   columns will be left-aligned. If \code{format = "html"}, the default is
+#'   left-align first column and center all remaining. May be a string to
+#'   indicate alignment rules for the complete table, like \code{"left"},
+#'   \code{"right"}, \code{"center"} or \code{"firstleft"} (to left-align first
+#'   column, center remaining); or maybe a string with abbreviated alignment
+#'   characters, where the length of the string must equal the number of columns,
+#'   for instance, \code{align = "lccrl"} would left-align the first column, center
 #'   the second and third, right-align column four and left-align the fifth
-#'   column.
+#'   column. For HTML-tables, may be one of \code{"center"}, \code{"left"} or
+#'   \code{"right"}.
+#' @param group_by Name of column in \code{x} that indicates grouping for tables.
+#'   Only applies when \code{format = "html"}. \code{group_by} is passed down
+#'   to \code{gt::gt(groupname_col = group_by)}.
 #' @inheritParams format_value
 #'
 #' @note The values for \code{caption}, \code{subtitle} and \code{footer}
@@ -33,7 +42,6 @@
 #' @examples
 #' cat(export_table(iris))
 #' cat(export_table(iris, sep = " ", header = "*", digits = 1))
-#'
 #' \dontrun{
 #' # colored footers
 #' data(iris)
@@ -59,15 +67,18 @@
 export_table <- function(x,
                          sep = " | ",
                          header = "-",
+                         empty_line = NULL,
                          digits = 2,
                          protect_integers = TRUE,
                          missing = "",
                          width = NULL,
                          format = NULL,
-                         caption = NULL,
+                         title = NULL,
+                         caption = title,
                          subtitle = NULL,
-                         align = NULL,
                          footer = NULL,
+                         align = NULL,
+                         group_by = NULL,
                          zap_small = FALSE) {
 
   # check args
@@ -79,10 +90,25 @@ export_table <- function(x,
     format <- "markdown"
   }
 
+  # if we have a list of data frame and HTML format, create a single
+  # data frame now...
+  if (identical(format, "html") && !is.data.frame(x) && is.list(x)) {
+    x <- do.call(rbind, lapply(x, function(i) {
+      attr_name <- .check_caption_attr_name(i)
+      i$Component <- attr(i, attr_name)[1]
+      i
+    }))
+  }
+
+
   # single data frame
   if (is.data.frame(x)) {
+    if (!is.null(title)) {
+      caption <- title
+    }
     if (is.null(caption)) {
-      caption <- attributes(x)$table_caption
+      attr_name <- .check_caption_attr_name(x)
+      caption <- attributes(x)[[attr_name]]
     }
     if (is.null(subtitle)) {
       subtitle <- attributes(x)$table_subtitle
@@ -101,13 +127,16 @@ export_table <- function(x,
       format = format,
       caption = caption,
       subtitle = subtitle,
-      align = align,
       footer = footer,
-      zap_small = zap_small
+      align = align,
+      group_by = group_by,
+      zap_small = zap_small,
+      empty_line = empty_line
     )
   } else if (is.list(x)) {
     # list of data frames
     tmp <- lapply(.compact_list(x), function(i) {
+      attr_name <- .check_caption_attr_name(i)
       .export_table(
         x = i,
         sep = sep,
@@ -117,11 +146,13 @@ export_table <- function(x,
         missing = missing,
         width = width,
         format = format,
-        caption = attributes(i)$table_caption,
+        caption = attributes(i)[[attr_name]],
         subtitle = attributes(i)$table_subtitle,
-        align = align,
         footer = attributes(i)$table_footer,
-        zap_small = zap_small
+        align = align,
+        group_by = group_by,
+        zap_small = zap_small,
+        empty_line = empty_line
       )
     })
     out <- c()
@@ -147,18 +178,24 @@ export_table <- function(x,
   out
 }
 
-#' @rdname export_table
-#' @export
-format_table <- export_table
 
 
+# check whether "table_caption" or its alias "table_title" is used as attribute
+.check_caption_attr_name <- function(x) {
+  attr_name <- "table_caption"
+  if (is.null(attr(x, attr_name, exact = TRUE)) && !is.null(attr(x, "table_title", exact = TRUE))) {
+    attr_name <- "table_title"
+  }
+  attr_name
+}
+
 
 
 # create matrix of raw table layout --------------------
 
 
-.export_table <- function(x, sep = " | ", header = "-", digits = 2, protect_integers = TRUE, missing = "", width = NULL, format = NULL, caption = NULL, subtitle = NULL, align = NULL, footer = NULL, zap_small = FALSE) {
-  df <- x
+.export_table <- function(x, sep = " | ", header = "-", digits = 2, protect_integers = TRUE, missing = "", width = NULL, format = NULL, caption = NULL, subtitle = NULL, footer = NULL, align = NULL, group_by = NULL, zap_small = FALSE, empty_line = NULL) {
+  df <- as.data.frame(x)
 
   # round all numerics
   col_names <- names(df)
@@ -176,29 +213,33 @@ format_table <- export_table
   names(df) <- col_names
   df[is.na(df)] <- as.character(missing)
 
-  # Add colnames as row
-  df <- rbind(colnames(df), df)
+  if (identical(format, "html")) {
+    out <- .format_html_table(df, caption = caption, subtitle = subtitle, footer = footer, align = align, group_by = group_by)
+  } else {
+    # Add colnames as row
+    df <- rbind(colnames(df), df)
 
-  # Align
-  aligned <- format(df, justify = "right")
+    # Align
+    aligned <- format(df, justify = "right")
 
-  # Center first row
-  first_row <- as.character(aligned[1, ])
-  for (i in 1:length(first_row)) {
-    aligned[1, i] <- format(trimws(first_row[i]), width = nchar(first_row[i]), justify = "right")
-  }
+    # Center first row
+    first_row <- as.character(aligned[1, ])
+    for (i in 1:length(first_row)) {
+      aligned[1, i] <- format(trimws(first_row[i]), width = nchar(first_row[i]), justify = "right")
+    }
 
-  final <- as.matrix(aligned)
+    final <- as.matrix(aligned)
 
-  # left-align first column (if a character or a factor)
-  if (!is.numeric(x[, 1])) {
-    final[, 1] <- format(trimws(final[, 1]), justify = "left")
-  }
+    # left-align first column (if a character or a factor)
+    if (!is.numeric(x[, 1])) {
+      final[, 1] <- format(trimws(final[, 1]), justify = "left")
+    }
 
-  if (format == "text") {
-    out <- .format_basic_table(final, header, sep, caption = caption, subtitle = subtitle, footer = footer)
-  } else if (format == "markdown") {
-    out <- .format_markdown_table(final, x, caption = caption, subtitle = subtitle, footer = footer, align = align)
+    if (format == "text") {
+      out <- .format_basic_table(final, header, sep, caption = caption, subtitle = subtitle, footer = footer, align = align, empty_line = empty_line)
+    } else if (format == "markdown") {
+      out <- .format_markdown_table(final, x, caption = caption, subtitle = subtitle, footer = footer, align = align)
+    }
   }
 
   out
@@ -212,12 +253,43 @@ format_table <- export_table
 # plain text formatting ------------------------
 
 
-.format_basic_table <- function(final, header, sep, caption = NULL, subtitle = NULL, footer = NULL) {
+.format_basic_table <- function(final, header, sep, caption = NULL, subtitle = NULL, footer = NULL, align = NULL, empty_line = NULL) {
+
+  # align table, if requested
+  if (!is.null(align) && length(align) == 1) {
+    for (i in 1:ncol(final)) {
+      align_char <- ""
+      if (align %in% c("left", "right", "center", "firstleft")) {
+        align_char <- ""
+      } else {
+        align_char <- substr(align, i, i)
+      }
+
+      # left alignment, or at least first line only left?
+      if (align == "left" || (align == "firstleft" && i == 1) || align_char == "l") {
+        final[, i] <- format(trimws(final[, i]), justify = "left")
+
+        # right-alignment
+      } else if (align == "right" || align_char == "r") {
+        final[, i] <- format(trimws(final[, i]), justify = "right")
+
+        # else, center
+      } else {
+        final[, i] <- format(trimws(final[, i]), justify = "centre")
+      }
+    }
+  }
+
   # Transform to character
   rows <- c()
   for (row in 1:nrow(final)) {
     final_row <- paste0(final[row, ], collapse = sep)
-    rows <- paste0(rows, final_row, sep = "\n")
+    # check if we have an empty row
+    if (!is.null(empty_line) && all(nchar(trimws(final[row, ])) == 0)) {
+      rows <- paste0(rows, paste0(rep_len(empty_line, nchar(final_row)), collapse = ""), sep = "\n")
+    } else {
+      rows <- paste0(rows, final_row, sep = "\n")
+    }
 
     # First row separation
     if (row == 1) {
@@ -259,6 +331,9 @@ format_table <- export_table
 # helper ----------------
 
 .paste_footers <- function(footer, rows) {
+  if (.is_empty_string(footer)) {
+    return(rows)
+  }
   if (length(footer) == 2 && .is_valid_colour(footer[2])) {
     footer <- .colour(footer[2], footer[1])
   }
@@ -351,8 +426,61 @@ format_table <- export_table
   }
 
   if (!is.null(footer)) {
-    rows <- c(rows, footer[1])
+    if (is.list(footer)) {
+      for (i in footer) {
+        if (!.is_empty_string(i)) {
+          rows <- c(rows, i[1])
+        }
+      }
+    } else if (!.is_empty_string(footer)) {
+      rows <- c(rows, footer[1])
+    }
   }
 
   rows
 }
+
+
+
+
+
+# html formatting ---------------------------
+
+.format_html_table <- function(final, caption = NULL, subtitle = NULL, footer = NULL, align = "center", group_by = NULL) {
+  if (!requireNamespace("gt", quietly = TRUE)) {
+    stop("Package 'gt' required to create HTML tables. Please install it.", call. = FALSE)
+  }
+
+  if (is.null(align)) {
+    align <- "firstleft"
+  }
+
+  group_by_columns <- c(intersect(c("Group", "Response", "Effects", "Component"), names(final)), group_by)
+  if (!length(group_by_columns)) {
+    group_by_columns <- NULL
+  }
+
+  tab <- gt::gt(final, groupname_col = group_by_columns)
+  header <- gt::tab_header(tab, title = caption, subtitle = subtitle)
+  footer <- gt::tab_source_note(header, source_note = footer)
+  out <- gt::cols_align(footer, align = "center")
+
+  # align columns
+  if (!is.null(out[["_boxhead"]]) && !is.null(out[["_boxhead"]]$column_align)) {
+    if (align == "firstleft") {
+      out[["_boxhead"]]$column_align[1] <- "left"
+    } else {
+      col_align <- c()
+      for (i in 1:nchar(align)) {
+        col_align <- c(col_align, switch(substr(align, i, i),
+          "l" = "left",
+          "r" = "right",
+          "center"
+        ))
+      }
+      out[["_boxhead"]]$column_align[1] <- col_align
+    }
+  }
+
+  out
+}
