@@ -14,11 +14,11 @@
 #'    }
 #'
 #' @examples
-#' library(lme4)
-#' data(sleepstudy)
-#'
-#' m <- lmer(Reaction ~ Days + (1 + Days | Subject), data = sleepstudy)
-#' find_random_slopes(m)
+#' if (require("lme4")) {
+#'   data(sleepstudy)
+#'   m <- lmer(Reaction ~ Days + (1 + Days | Subject), data = sleepstudy)
+#'   find_random_slopes(m)
+#' }
 #' @export
 find_random_slopes <- function(x) {
   random_slopes <- vector(mode = "list")
@@ -44,9 +44,13 @@ find_random_slopes <- function(x) {
   if (!is.list(fr)) fr <- list(fr)
 
   random_slope <- lapply(fr, function(forms) {
-    pattern <- gsub("(.*)\\|(.*)", "\\1", .safe_deparse(forms))
+    if (grepl("(.*)\\|(.*)\\|(.*)", .safe_deparse(forms))) {
+      pattern <- "(.*)\\|(.*)\\|(.*)"
+    } else {
+      pattern <- "(.*)\\|(.*)"
+    }
+    pattern <- gsub(pattern, "\\1", .safe_deparse(forms))
     re <- all.vars(forms)
-
     re[sapply(re, function(x) {
       grepl(x, pattern, fixed = TRUE)
     })]
