@@ -21,10 +21,12 @@
 #'   columns with transformed values.
 #'
 #' @examples
-#' data(cbpp, package = "lme4")
-#' cbpp$trials <- cbpp$size - cbpp$incidence
-#' m <- glm(cbind(incidence, trials) ~ period, data = cbpp, family = binomial)
-#' head(get_data(m))
+#' if (require("lme4")) {
+#'   data(cbpp, package = "lme4")
+#'   cbpp$trials <- cbpp$size - cbpp$incidence
+#'   m <- glm(cbind(incidence, trials) ~ period, data = cbpp, family = binomial)
+#'   head(get_data(m))
+#' }
 #' @importFrom stats model.frame na.omit
 #' @export
 get_data <- function(x, ...) {
@@ -76,6 +78,20 @@ get_data.data.frame <- function(x, ...) {
 }
 
 
+#' @export
+get_data.summary.lm <- function(x, ...) {
+  mf <- tryCatch(
+    {
+      .get_data_from_env(x)[, all.vars(x$terms), drop = FALSE]
+    },
+    error = function(x) {
+      NULL
+    }
+  )
+  .prepare_get_data(x, mf)
+}
+
+
 
 
 
@@ -90,8 +106,7 @@ get_data.gee <- function(x, effects = c("all", "fixed", "random"), verbose = TRU
   mf <- tryCatch(
     {
       dat <- .get_data_from_env(x)
-      switch(
-        effects,
+      switch(effects,
         all = dat[, find_variables(x, flatten = TRUE), drop = FALSE],
         fixed = dat[, find_variables(x, effects = "fixed", flatten = TRUE), drop = FALSE],
         random = dat[, find_random(x, flatten = TRUE), drop = FALSE]
@@ -219,8 +234,7 @@ get_data.zcpglm <- function(x, component = c("all", "conditional", "zi", "zero_i
     mf_zero <- NULL
   }
 
-  mf <- switch(
-    component,
+  mf <- switch(component,
     "all" = do.call(cbind, .compact_list(list(mf_tweedie, mf_zero))),
     "conditional" = mf_tweedie,
     "zi" = ,
@@ -277,8 +291,7 @@ get_data.merMod <- function(x, effects = c("all", "fixed", "random"), verbose =
 
   mf <- tryCatch(
     {
-      switch(
-        effects,
+      switch(effects,
         fixed = stats::model.frame(x, fixed.only = TRUE),
         all = stats::model.frame(x, fixed.only = FALSE),
         random = stats::model.frame(x, fixed.only = FALSE)[, find_random(x, split_nested = TRUE, flatten = TRUE), drop = FALSE]
@@ -306,8 +319,7 @@ get_data.MANOVA <- function(x, effects = c("all", "fixed", "random"), verbose =
 
   mf <- tryCatch(
     {
-      switch(
-        effects,
+      switch(effects,
         fixed = .remove_column(x$input$data, x$input$subject),
         all = x$input$data,
         random = x$input$data[, x$input$subject, drop = FALSE]
@@ -333,8 +345,7 @@ get_data.cpglmm <- function(x, effects = c("all", "fixed", "random"), verbose =
 
   mf <- tryCatch(
     {
-      switch(
-        effects,
+      switch(effects,
         fixed = dat[, find_predictors(x, effects = "fixed", flatten = TRUE), drop = FALSE],
         all = dat,
         random = dat[, find_random(x, split_nested = TRUE, flatten = TRUE), drop = FALSE]
@@ -359,8 +370,7 @@ get_data.glmm <- function(x, effects = c("all", "fixed", "random"), verbose = TR
 
   mf <- tryCatch(
     {
-      switch(
-        effects,
+      switch(effects,
         fixed = dat[, find_predictors(x, effects = "fixed", flatten = TRUE), drop = FALSE],
         all = dat,
         random = dat[, find_random(x, split_nested = TRUE, flatten = TRUE), drop = FALSE]
@@ -380,8 +390,7 @@ get_data.mixor <- function(x, effects = c("all", "fixed", "random"), verbose = T
 
   mf <- tryCatch(
     {
-      switch(
-        effects,
+      switch(effects,
         fixed = stats::model.frame(x),
         all = cbind(stats::model.frame(x), x$id),
         random = data.frame(x$id)
@@ -410,8 +419,7 @@ get_data.glmmadmb <- function(x, effects = c("all", "fixed", "random"), ...) {
 
   mf <- tryCatch(
     {
-      switch(
-        effects,
+      switch(effects,
         fixed = fixed_data,
         all = cbind(fixed_data, random_data),
         random = random_data
@@ -460,8 +468,7 @@ get_data.sem <- function(x, effects = c("all", "fixed", "random"), ...) {
   mf <- tryCatch(
     {
       dat <- .get_data_from_env(x)
-      switch(
-        effects,
+      switch(effects,
         all = dat[, find_variables(x, flatten = TRUE), drop = FALSE],
         fixed = dat[, find_variables(x, effects = "fixed", flatten = TRUE), drop = FALSE],
         random = dat[, find_random(x, flatten = TRUE), drop = FALSE]
@@ -546,8 +553,7 @@ get_data.BBmm <- function(x, effects = c("all", "fixed", "random"), ...) {
   mf <- tryCatch(
     {
       dat <- .get_data_from_env(x)[, find_variables(x, flatten = TRUE), drop = FALSE]
-      switch(
-        effects,
+      switch(effects,
         all = dat[, find_variables(x, flatten = TRUE), drop = FALSE],
         fixed = dat[, find_variables(x, effects = "fixed", flatten = TRUE), drop = FALSE],
         random = dat[, find_random(x, flatten = TRUE), drop = FALSE]
@@ -567,8 +573,7 @@ get_data.BBmm <- function(x, effects = c("all", "fixed", "random"), ...) {
 get_data.glimML <- function(x, effects = c("all", "fixed", "random"), ...) {
   effects <- match.arg(effects)
   dat <- x@data
-  mf <- switch(
-    effects,
+  mf <- switch(effects,
     all = dat[, find_variables(x, flatten = TRUE), drop = FALSE],
     fixed = dat[, find_variables(x, effects = "fixed", flatten = TRUE), drop = FALSE],
     random = dat[, find_random(x, flatten = TRUE), drop = FALSE]
@@ -581,6 +586,7 @@ get_data.glimML <- function(x, effects = c("all", "fixed", "random"), ...) {
 
 
 
+
 # sem models -------------------------------------
 
 #' @export
@@ -782,6 +788,12 @@ get_data.ivreg <- function(x, ...) {
 get_data.iv_robust <- get_data.ivreg
 
 
+#' @export
+get_data.ivprobit <- function(x, ...) {
+  .prepare_get_data(x, stats::na.omit(as.data.frame(x$mr1)))
+}
+
+
 #' @export
 get_data.bife <- function(x, effects = c("all", "fixed", "random"), ...) {
   effects <- match.arg(effects)
@@ -878,9 +890,8 @@ get_data.MCMCglmm <- function(x, effects = c("all", "fixed", "random"), ...) {
       mf <- env_dataframes[matchframe][1]
       if (!is.na(mf)) {
         dat <- get(mf)
-        switch(
-          effects,
-          fixed = dat[, setdiff(colnames(dat), find_random(x, flatten = T)), drop = FALSE],
+        switch(effects,
+          fixed = dat[, setdiff(colnames(dat), find_random(x, flatten = TRUE)), drop = FALSE],
           all = dat,
           random = dat[, find_random(x, flatten = TRUE), drop = FALSE]
         )
@@ -1106,8 +1117,7 @@ get_data.LORgee <- function(x, effects = c("all", "fixed", "random"), ...) {
   mf <- tryCatch(
     {
       dat <- .get_data_from_env(x)[, find_variables(x, flatten = TRUE), drop = FALSE]
-      switch(
-        effects,
+      switch(effects,
         all = dat[, find_variables(x, flatten = TRUE), drop = FALSE],
         fixed = dat[, find_variables(x, effects = "fixed", flatten = TRUE), drop = FALSE],
         random = dat[, find_random(x, flatten = TRUE), drop = FALSE]
@@ -1293,6 +1303,10 @@ get_data.meta_bma <- function(x, ...) {
 get_data.meta_fixed <- get_data.meta_random
 
 
+#' @export
+get_data.ivFixed <- get_data.rma
+
+
 #' @export
 get_data.mipo <- function(x, ...) {
   tryCatch(
@@ -1311,36 +1325,7 @@ get_data.mipo <- function(x, ...) {
 get_data.htest <- function(x, ...) {
   out <- NULL
   if (!is.null(x$data.name)) {
-    out <- tryCatch(
-      {
-        data_name <- unlist(strsplit(x$data.name, " (and|by) "))
-        data_call <- lapply(data_name, str2lang)
-        columns <- lapply(data_call, eval)
-
-        if (!grepl(" (and|by) ", x$data.name) && grepl("^McNemar", x$method)) {
-          # preserve table data for McNemar
-          return(as.table(columns[[1]]))
-        } else {
-          max_len <- max(sapply(columns, length))
-          for (i in 1:length(columns)) {
-            columns[[i]] <- c(columns[[i]], rep(NA, max_len - length(columns[[i]])))
-          }
-          d <- as.data.frame(columns)
-        }
-
-        if (ncol(d) > 2) {
-          colnames(d) <- paste0("x", 1:ncol(d))
-        } else if (ncol(d) == 2) {
-          colnames(d) <- c("x", "y")
-        } else {
-          colnames(d) <- "x"
-        }
-        d
-      },
-      error = function(e) {
-        NULL
-      }
-    )
+    out <- .retrieve_htest_data(x)
   }
   out
 }
