@@ -142,6 +142,9 @@ link_function.feis <- link_function.lm
 #' @export
 link_function.ivreg <- link_function.lm
 
+#' @export
+link_function.ivFixed <- link_function.lm
+
 #' @export
 link_function.plm <- link_function.lm
 
@@ -215,12 +218,33 @@ link_function.mlogit <- link_function.multinom
 #' @export
 link_function.coxph <- link_function.multinom
 
+#' @export
+link_function.coxr <- link_function.multinom
+
 #' @export
 link_function.survfit <- link_function.multinom
 
 #' @export
 link_function.coxme <- link_function.multinom
 
+#' @export
+link_function.riskRegression <- link_function.multinom
+
+#' @export
+link_function.comprisk <- link_function.multinom
+
+
+
+
+
+
+# Probit link ------------------------
+
+
+#' @export
+link_function.ivprobit <- function(x, ...) {
+  stats::make.link(link = "probit")$linkfun
+}
 
 
 
@@ -343,6 +367,12 @@ link_function.logitor <- link_function.logitmfx
 
 
 
+#' @export
+link_function.Rchoice <- function(x, ...) {
+  stats::make.link(link = x$link)$linkfun
+}
+
+
 #' @export
 link_function.merModList <- function(x, ...) {
   link_function.default(x[[1]], ...)
@@ -367,8 +397,7 @@ link_function.mira <- function(x, ...) {
 
 #' @export
 link_function.robmixglm <- function(x, ...) {
-  switch(
-    tolower(x$family),
+  switch(tolower(x$family),
     gaussian = stats::make.link(link = "identity")$linkfun,
     binomial = stats::make.link(link = "logit")$linkfun,
     gamma = stats::make.link(link = "inverse")$linkfun,
@@ -381,8 +410,7 @@ link_function.robmixglm <- function(x, ...) {
 
 #' @export
 link_function.MCMCglmm <- function(x, ...) {
-  switch(
-    x$Residual$original.family,
+  switch(x$Residual$original.family,
     "cengaussian" = ,
     "gaussian" = stats::gaussian(link = "identity")$linkfun,
     "categorical" = ,
@@ -421,8 +449,7 @@ link_function.fixest <- function(x, ...) {
   } else if (inherits(x$family, "family")) {
     x$family$linkfun
   } else {
-    link <- switch(
-      x$family,
+    link <- switch(x$family,
       "poisson" = ,
       "negbin" = "log",
       "logit" = "logit",
@@ -520,8 +547,7 @@ link_function.glmmadmb <- function(x, ...) {
 
 #' @export
 link_function.glmm <- function(x, ...) {
-  switch(
-    tolower(x$family.glmm$family.glmm),
+  switch(tolower(x$family.glmm$family.glmm),
     "bernoulli.glmm" = ,
     "binomial.glmm" = stats::make.link("logit")$linkfun,
     "poisson.glmm" = stats::make.link("log")$linkfun,
@@ -536,8 +562,7 @@ link_function.glmm <- function(x, ...) {
 link_function.gamlss <- function(x, what = c("mu", "sigma", "nu", "tau"), ...) {
   what <- match.arg(what)
   faminfo <- get(x$family[1], asNamespace("gamlss"))()
-  switch(
-    what,
+  switch(what,
     "mu" = faminfo$mu.linkfun,
     "sigma" = faminfo$sigma.linkfun,
     "nu" = faminfo$nu.linkfun,
@@ -605,8 +630,7 @@ link_function.vglm <- function(x, ...) {
 
 #' @export
 link_function.polr <- function(x, ...) {
-  link <- switch(
-    x$method,
+  link <- switch(x$method,
     logistic = "logit",
     probit = "probit",
     "log"
@@ -618,8 +642,7 @@ link_function.polr <- function(x, ...) {
 
 #' @export
 link_function.svyolr <- function(x, ...) {
-  link <- switch(
-    x$method,
+  link <- switch(x$method,
     logistic = "logit",
     probit = "probit",
     "log"
@@ -634,8 +657,7 @@ link_function.svyolr <- function(x, ...) {
 #' @export
 link_function.betareg <- function(x, what = c("mean", "precision"), ...) {
   what <- match.arg(what)
-  switch(
-    what,
+  switch(what,
     "mean" = x$link$mean$linkfun,
     "precision" = x$link$precision$linkfun
   )
@@ -650,8 +672,7 @@ link_function.DirichletRegModel <- function(x, what = c("mean", "precision"), ..
   if (x$parametrization == "common") {
     stats::make.link("logit")$linkfun
   } else {
-    switch(
-      what,
+    switch(what,
       "mean" = stats::make.link("logit")$linkfun,
       "precision" = stats::make.link("log")$linkfun
     )
@@ -663,8 +684,7 @@ link_function.DirichletRegModel <- function(x, what = c("mean", "precision"), ..
 #' @importFrom stats poisson
 #' @export
 link_function.gbm <- function(x, ...) {
-  switch(
-    x$distribution$name,
+  switch(x$distribution$name,
     laplace = ,
     tdist = ,
     gaussian = stats::gaussian(link = "identity")$linkfun,
