@@ -146,6 +146,9 @@ link_inverse.aovlist <- link_inverse.lm
 #' @export
 link_inverse.ivreg <- link_inverse.lm
 
+#' @export
+link_inverse.ivFixed <- link_inverse.lm
+
 #' @export
 link_inverse.iv_robust <- link_inverse.lm
 
@@ -212,8 +215,7 @@ link_inverse.speedlm <- link_inverse.lm
 #' @export
 link_inverse.betareg <- function(x, what = c("mean", "precision"), ...) {
   what <- match.arg(what)
-  switch(
-    what,
+  switch(what,
     "mean" = x$link$mean$linkinv,
     "precision" = x$link$precision$linkinv
   )
@@ -228,8 +230,7 @@ link_inverse.DirichletRegModel <- function(x, what = c("mean", "precision"), ...
   if (x$parametrization == "common") {
     stats::make.link("logit")$linkinv
   } else {
-    switch(
-      what,
+    switch(what,
       "mean" = stats::make.link("logit")$linkinv,
       "precision" = stats::make.link("log")$linkinv
     )
@@ -259,6 +260,15 @@ link_inverse.BBmm <- link_inverse.gmnl
 #' @export
 link_inverse.coxph <- link_inverse.gmnl
 
+#' @export
+link_inverse.riskRegression <- link_inverse.gmnl
+
+#' @export
+link_inverse.comprisk <- link_inverse.gmnl
+
+#' @export
+link_inverse.coxr <- link_inverse.gmnl
+
 #' @export
 link_inverse.survfit <- link_inverse.gmnl
 
@@ -286,6 +296,18 @@ link_inverse.multinom <- link_inverse.gmnl
 
 
 
+# Probit link ------------------------
+
+
+#' @export
+link_inverse.ivprobit <- function(x, ...) {
+  stats::make.link(link = "probit")$linkinv
+}
+
+
+
+
+
 # Log-links ---------------------------------------
 
 
@@ -377,6 +399,12 @@ link_inverse.negbinirr <- link_inverse.logitmfx
 # Other models ----------------------------
 
 
+#' @export
+link_inverse.Rchoice <- function(x, ...) {
+  stats::make.link(link = x$link)$linkinv
+}
+
+
 #' @export
 link_inverse.merModList <- function(x, ...) {
   link_inverse.default(x[[1]], ...)
@@ -385,8 +413,7 @@ link_inverse.merModList <- function(x, ...) {
 
 #' @export
 link_inverse.robmixglm <- function(x, ...) {
-  switch(
-    tolower(x$family),
+  switch(tolower(x$family),
     gaussian = stats::make.link(link = "identity")$linkinv,
     binomial = stats::make.link(link = "logit")$linkinv,
     gamma = stats::make.link(link = "inverse")$linkinv,
@@ -435,8 +462,7 @@ link_inverse.fixest <- function(x, ...) {
   } else if (inherits(x$family, "family")) {
     x$family$linkinv
   } else {
-    link <- switch(
-      x$family,
+    link <- switch(x$family,
       "poisson" = ,
       "negbin" = "log",
       "logit" = "logit",
@@ -524,8 +550,7 @@ link_inverse.glmmTMB <- function(x, ...) {
 
 #' @export
 link_inverse.MCMCglmm <- function(x, ...) {
-  switch(
-    x$Residual$original.family,
+  switch(x$Residual$original.family,
     "cengaussian" = ,
     "gaussian" = stats::gaussian(link = "identity")$linkinv,
     "categorical" = ,
@@ -544,8 +569,7 @@ link_inverse.MCMCglmm <- function(x, ...) {
 
 #' @export
 link_inverse.glmm <- function(x, ...) {
-  switch(
-    tolower(x$family.glmm$family.glmm),
+  switch(tolower(x$family.glmm$family.glmm),
     "bernoulli.glmm" = ,
     "binomial.glmm" = stats::make.link("logit")$linkinv,
     "poisson.glmm" = stats::make.link("log")$linkinv,
@@ -571,8 +595,7 @@ link_inverse.stanmvreg <- function(x, ...) {
 
 #' @export
 link_inverse.gbm <- function(x, ...) {
-  switch(
-    x$distribution$name,
+  switch(x$distribution$name,
     laplace = ,
     tdist = ,
     gaussian = stats::gaussian(link = "identity")$linkinv,
@@ -601,8 +624,7 @@ link_inverse.brmsfit <- function(x, ...) {
 link_inverse.gamlss <- function(x, what = c("mu", "sigma", "nu", "tau"), ...) {
   what <- match.arg(what)
   faminfo <- get(x$family[1], asNamespace("gamlss"))()
-  switch(
-    what,
+  switch(what,
     "mu" = faminfo$mu.linkinv,
     "sigma" = faminfo$sigma.linkinv,
     "nu" = faminfo$nu.linkinv,
