@@ -24,6 +24,11 @@ if (.runThisTest) {
       expect_null(find_statistic(m5))
     })
 
+    test_that("n_parameters", {
+      expect_equal(n_parameters(m1), 65)
+      expect_equal(n_parameters(m1, effects = "fixed"), 5)
+    })
+
     test_that("model_info", {
       expect_true(model_info(m3)$is_trial)
       expect_true(model_info(m5)[[1]]$is_zero_inflated)
@@ -584,7 +589,7 @@ if (.runThisTest) {
               "persons.2",
               "persons.3",
               "persons.4",
-              "zi_Intercept"
+              "(Intercept)"
             )
           ),
           class = c("clean_parameters", "data.frame"),
@@ -592,7 +597,8 @@ if (.runThisTest) {
             NA,
             -16L
           )
-        )
+        ),
+        ignore_attr = TRUE
       )
 
       expect_equal(
@@ -794,7 +800,8 @@ if (.runThisTest) {
           ),
           class = c("clean_parameters", "data.frame"),
           row.names = c(NA, -30L)
-        )
+        ),
+        ignore_attr = TRUE
       )
     })
   }
