@@ -1,11 +1,16 @@
-osx <- tryCatch({
-  si <- Sys.info()
-  if (!is.null(si["sysname"])) {
-    si["sysname"] == "Darwin" || grepl("^darwin", R.version$os)
-  } else {
+osx <- tryCatch(
+  {
+    si <- Sys.info()
+    if (!is.null(si["sysname"])) {
+      si["sysname"] == "Darwin" || grepl("^darwin", R.version$os)
+    } else {
+      FALSE
+    }
+  },
+  error = function(e) {
     FALSE
   }
-})
+)
 
 unloadNamespace("gam")
 
@@ -128,6 +133,6 @@ if (!osx && require("testthat") && require("insight") && require("gamm4")) {
   })
 
   test_that("find_statistic", {
-    expect_error(find_statistic(m1))
+    expect_null(find_statistic(m1))
   })
 }
