@@ -26,6 +26,25 @@ if (require("testthat") &&
     expect_true(model_info(m2)$is_linear)
   })
 
+  test_that("loglik", {
+    expect_equal(get_loglikelihood(m1), logLik(m1), ignore_attr = TRUE)
+    expect_equal(get_loglikelihood(m2), logLik(m2), ignore_attr = TRUE)
+  })
+
+  test_that("get_df", {
+    expect_equal(get_df(m1), df.residual(m1), ignore_attr = TRUE)
+    expect_equal(get_df(m2), df.residual(m2), ignore_attr = TRUE)
+    expect_equal(get_df(m1, type = "model"), attr(logLik(m1), "df"), ignore_attr = TRUE)
+    expect_equal(get_df(m2, type = "model"), attr(logLik(m2), "df"), ignore_attr = TRUE)
+  })
+
+  test_that("n_parameters", {
+    expect_equal(n_parameters(m1), 2)
+    expect_equal(n_parameters(m2), 2)
+    expect_equal(n_parameters(m1, effects = "random"), 2)
+    expect_equal(n_parameters(m2, effects = "random"), 3)
+  })
+
   test_that("find_predictors", {
     expect_equal(
       find_predictors(m1, effects = "all"),
@@ -413,4 +432,9 @@ if (require("testthat") &&
     expect_identical(find_statistic(m1), "t-statistic")
     expect_identical(find_statistic(m2), "t-statistic")
   })
+
+  test_that("get_call", {
+    expect_equal(class(get_call(m1)), "call")
+    expect_equal(class(get_call(m2)), "call")
+  })
 }
